@@ -1,24 +1,9 @@
-package DBD::Oracle::Troubleshooting;
-{
-  $DBD::Oracle::Troubleshooting::VERSION = '1.45_00';
-}
-BEGIN {
-  $DBD::Oracle::Troubleshooting::AUTHORITY = 'cpan:PYTHIAN';
-}
-#ABSTRACT: Tips and Hints to Troubleshoot DBD::Oracle
-
-
-__END__
 =pod
 
 =head1 NAME
 
 DBD::Oracle::Troubleshooting - Tips and Hints to Troubleshoot DBD::Oracle
 
-=head1 VERSION
-
-version 1.45_00
-
 =head1 CONNECTING TO ORACLE
 
 If you are reading this it is assumed that you have successfully
@@ -45,6 +30,7 @@ For Windows the solution is to add this value to you PATH
 
   PATH=c:\app\oracle\product\xx.x.x;%PATH%
 
+
 If you get past this stage and get a
 
   ORA-12154: TNS:could not resolve the connect identifier specified
@@ -76,21 +62,6 @@ Protocol Adapter".
 If it generates any errors which look relevant then please talk to your
 Oracle technical support (and not the dbi-users mailing list).
 
-=head2 Connecting using a bequeather
-
-If you are using a bequeather to connect to a server
-on the same host as the client, you might have 
-to add 
-
-    bequeath_detach = yes
-
-to your sqlnet.ora file or you won't be able to safely use fork/system
-functions in Perl.
-
-See the discussion at
-L<http://www.nntp.perl.org/group/perl.dbi.dev/2012/02/msg6837.html>
-and L<http://www.nntp.perl.org/group/perl.dbi.users/2009/06/msg34023.html>
-for more gory details.
 
 =head1 USING THE LONG TYPES
 
@@ -126,6 +97,7 @@ It turns out that now it is necessary to edit the same file and append
 this and then run "genclntsh", the libclntsh is properly generated and
 the linkage with DBD::Oracle proceeds properly.
 
+
 =head2 cc1: invalid option `tune=pentium4'" error
 
 If you get the above it seems that eiter your Perl or OS where compiled with a different version of GCC or the GCC that is on your system is very old.
@@ -182,7 +154,7 @@ To get 10Xe to compile correctly I had to add $ORACLE_HOME/lib to the LD_LIBRARY
 as you would for an install against 10g Standard Edition, Standard Edition One, or 
 Enterprise Edition 
 
-=head2 UTF8 bug in Oracle  9.2.0.5.0 and 9.2.0.7.0
+=head2  UTF8 bug in Oracle  9.2.0.5.0 and 9.2.0.7.0
 
 DBD::Oracle seems to hit some sort of bug with the above two versions of DB.
 The bug seems to hit when you when the Oracle database charset: US7ASCII and the Oracle nchar charset: AL16UTF16 and it has also
@@ -201,6 +173,7 @@ So far there is no patch for this but here are some work arounds
     or this way
 
     utf8::downgrade($parameter, 1);
+	
 
 =head1 CYGWIN
 
@@ -320,11 +293,11 @@ in the first table in above list, and not as one would normally
 expect in the process table.
 
 Installing DBI and DBD::Oracle has influence upon this since in
-both cases a few environment variables are read or set in the
+both cases a few enviroment variables are read or set in the
 test phase.
 For DBI it is the logical SYS$SCRATCH, which is a JOB logical.
 For DBD-Oracle it is when testing a new feature in the Oracle 
-RDBMS: UTF8 and UTF16 character set functionality, and in order 
+RDBMS: UTF8 and UTF16 character set functionallity, and in order 
 to do this it sets and unsets the related environment variables 
 NLS_NCHAR and NLS_LANG.
 
@@ -363,46 +336,4 @@ oracle table implementation, and no UTF support.
 Oracle 9.0 is uncertain, since testing has not been possible yet,
 but the remedy will not hurt :)
 
-=head1 Miscellaneous
-
-=head2 Crash with an open connection and Module::Runtime in mod_perl2
-
-See RT 72989 (https://rt.cpan.org/Ticket/Display.html?id=72989)
-
-Apache2 MPM Prefork with mod_perl2 will crash if Module::Runtime is
-loaded, and an Oracle connection is opened through PerlRequire (before
-forking).
-
-It looks like this was fixed in 0.012 of Module::Runtime.
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Tim Bunce <timb@cpan.org>
-
-=item *
-
-John Scoles
-
-=item *
-
-Yanick Champoux <yanick@cpan.org>
-
-=item *
-
-Martin J. Evans <mjevans@cpan.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 1994 by Tim Bunce.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
